#!/bin/csh

# Generation of delays for random acquisition on a Varian spectrometer
# Note that the programs "qvoronoi" and "qconvex" should be obtained from www.qhull.org
# The script should be modified to start the appropriate executables (MacOS or Linux)
# Institut de Biologie Structurale Jean-Pierre Ebel - Grenoble

# Parameters for point coordinates / areas generator

set filename = "DataLinux"
set sw1 = 10000				# spectral width in indirect dimension 1
set sw2 = 1125				# spectral width in indirect dimension 2
set size1 = 118				# Maximum number of point in indirect dimension 1 if it was a cartesian grid
set size2 = 156				# Maximum number of point in indirect dimension 2 if it was a cartesian grid
set nbofpoint = 3120			# Number of points you want to sample.
setenv GSL_RNG_TYPE mt19937		# Name of the random number generator 
setenv GSL_RNG_SEED 123456		# Value of the seed you use for the generator
set sigmfact1 = 1			# if > 1 => probability distribution narrower in indirect dimension 1,
set sigmfact2 = 1			# the same in indirect dimension 2. By default (size) = 50% .

# Generation :


Coord_gen  -name $filename -sw1 $sw1 -sw2 $sw2 -size1 $size1 -size2 $size2 -n $nbofpoint -sigmfact1 $sigmfact1 -sigmfact2 $sigmfact2

date >> ${filename}.info 

rm ${filename}.area

foreach ll (0 1 2 3 4 5 6 7 8 9)
foreach kk (0 1 2 3 4 5 6 7 8 9)
foreach jj (0 1 2 3 4 5 6 7 8 9)

if ( $ll$kk$jj'9' < $nbofpoint ) then

	echo
	echo -n "area  " $ll$kk$jj"0  computed "
endif
	
foreach ii (0 1 2 3 4 5 6 7 8 9)

if ( $ll$kk$jj$ii < $nbofpoint ) then
	


	echo  -n $ll$kk$jj$ii "  " >> ${filename}.area
	cat $filename 			\
	| qvoronoi QV$ll$kk$jj$ii p 	\
	| qconvex FS 			\
	| grep 2 			\
	| awk '{print $3 }'>> ${filename}.area
	
	
endif

end
end
end
end
